@@ -9,14 +9,15 @@ class ResponseFactory:
     @staticmethod
     def create_object_from_raw_response(raw_response):
         try:
-            dict_res = json.loads(raw_response, parse_float=lambda f: f, parse_int=lambda i: i)
+            dict_res = json.loads(
+                raw_response, parse_float=lambda f: f, parse_int=lambda i: i)
         except Exception:
             try:
                 dict_res = xmltodict.parse(raw_response, 'UTF-8')
                 dict_res = dict_res['result']
             except Exception:
-                raise MoceanErrorException('unable to parse response, ' + raw_response)
-
+                raise MoceanErrorException(
+                    'unable to parse response, ' + raw_response)
         return DotMapExtended(dict_res)
 
 
@@ -30,11 +31,11 @@ class DotMapExtended(DotMap):
         return self
 
     def toDict(self):
-        dict_value = super(DotMapExtended, self).toDict()
-        if '_DotMapExtended__raw_response' in dict_value:
-            del dict_value['_DotMapExtended__raw_response']
+        # dict_value = super(DotMapExtended, self).toDict()
+        if '_DotMapExtended__raw_response' in self.keys():
+            del self['_DotMapExtended__raw_response']
 
-        return dict_value
+        return self
 
     def __str__(self):
         return self.__raw_response
