@@ -11,7 +11,8 @@ class AbstractMc(object):
     def get_request_data(self):
         for required_key in self.required_key():
             if required_key not in self._params:
-                raise RequiredFieldException("%s is mandatory field, %s" % (required_key, self.__class__.__name__))
+                raise RequiredFieldException("%s is mandatory field, %s" % (
+                    required_key, self.__class__.__name__))
 
         self._params['action'] = self.action()
         return self._params
